function dgt_params = generate_dgt_parameters(win_type, approx_win_len, hop, nbins, sig_len)
%% dgt_params = generate_dgt_parameters(win_type, approx_win_len, hop, nbins, sig_len)
% 
% function that generates the dgt parameters.The functions used for
% the DGT are those of ltfat and not those of Matlab

%     Inputs:
%      - win_type : str. It can be either a hanning (hann) or gauss window.
%      - approx_win_len :  window length
%      - hop :  length of time shift.
%      - nbins: number of channels.
%       -sig_len: length of input signal.
%
%   Outputs: dgt_params -  struct containing dgt parameters
%
%
% Author : A. Marina KREME
% e-mail : ama-marina.kreme@lis-lab.fr/ama-marina.kreme@univ-amu.fr
% Created: 2020-28-01
%%



win_type = lower(win_type);

if ~ischar(win_type)
    error('%s: The window type must be a string',upper(mfilename));
end


ch1= strcmp('hann', win_type);
ch2 = strcmp('gauss', win_type);

if ch1==0 && ch2==0
    error('%s: Incorrect window type. Please choose hann or gauss.',upper(mfilename));
end
%%



input_win_len = 2^(round(log2(approx_win_len)));

if input_win_len ~= approx_win_len
    warning('Input window length %.2f has been changed to %.2f.',approx_win_len, input_win_len);
end

win_len = input_win_len;

%%

L = sig_len;

switch win_type
    case 'hann'
        [win, info]= gabwin({'tight',{win_type, win_len}}, hop, nbins, L);
        
    case  'gauss'
        tfr = (pi*win_len^2)/(4*sig_len*log(2));
        [win, info]= gabwin({'tight',{win_type, tfr}}, hop, nbins,L);
               
end

%%

dgt_params.win_len = win_len;
dgt_params.hop = hop;
dgt_params.nbins= nbins;
dgt_params.win_type = win_type;
dgt_params.win = win;
dgt_params.info = info;


end

